Class: FeatureHub::Sdk::ValueInterceptor
- Inherits:
-
Object
- Object
- FeatureHub::Sdk::ValueInterceptor
- Defined in:
- lib/feature_hub/sdk/interceptors.rb,
sig/feature_hub/featurehub.rbs
Overview
Holds the pattern for a value based interceptor, which could come from a file, or whatever they are not typed
Direct Known Subclasses
Instance Method Summary collapse
- #close ⇒ void
- #intercepted_value(_feature_key, _repository, _feature_state) ⇒ [bool, (bool? | String? | Float?)]
Instance Method Details
#close ⇒ void
This method returns an undefined value.
32 |
# File 'lib/feature_hub/sdk/interceptors.rb', line 32 def close; end |
#intercepted_value(_feature_key, _repository, _feature_state) ⇒ [bool, (bool? | String? | Float?)]
28 29 30 |
# File 'lib/feature_hub/sdk/interceptors.rb', line 28 def intercepted_value(_feature_key, _repository, _feature_state) [false, nil] end |