Class: FeatureHub::Sdk::ValueInterceptor
- Inherits:
-
Object
- Object
- FeatureHub::Sdk::ValueInterceptor
show all
- Defined in:
- lib/feature_hub/sdk/interceptors.rb
Overview
Holds the pattern for a value based interceptor, which could come from a file, or whatever they are not typed
Instance Method Summary
collapse
Instance Method Details
#close ⇒ Object
32
|
# File 'lib/feature_hub/sdk/interceptors.rb', line 32
def close; end
|
#intercepted_value(_feature_key, _repository, _feature_state) ⇒ Object
28
29
30
|
# File 'lib/feature_hub/sdk/interceptors.rb', line 28
def intercepted_value(_feature_key, _repository, _feature_state)
[false, nil]
end
|